@@ -20,11 +20,9 @@
 
 import logging
 
-# pylint: disable=E0611
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Gdk
-# pylint: enable=E0611
 
 from virtManager import uiutil
 from virtManager.baseclass import vmmGObjectUI
@@ -283,9 +281,6 @@ class vmmCreateVolume(vmmGObjectUI):
             self.show_err(_("Uncaught error validating input: %s") % str(e))
             return
 
-        logging.debug("Creating volume with xml:\n%s",
-                      self.vol.get_xml_config())
-
         self.topwin.set_sensitive(False)
         self.topwin.get_window().set_cursor(
             Gdk.Cursor.new(Gdk.CursorType.WATCH))
