@@ -22,11 +22,9 @@ import traceback
 import logging
 import threading
 
-# pylint: disable=E0611
 from gi.repository import Gdk
 from gi.repository import GLib
 from gi.repository import Gtk
-# pylint: enable=E0611
 
 import libvirt
 from virtinst import util
@@ -399,7 +397,7 @@ class vmmMigrateDialog(vmmGObjectUI):
         origuri = self.conn.get_uri()
 
         can_migrate = False
-        desc = destconn.get_pretty_desc_inactive()
+        desc = destconn.get_pretty_desc()
         reason = ""
         desturi = destconn.get_uri()
 
