@@ -53,14 +53,20 @@ def _setup_gsettings_path(schemadir):
     schema and use it directly
     """
     import subprocess
+    from distutils.spawn import find_executable
+
+    exe = find_executable("glib-compile-schemas")
+    if not exe:
+        raise RuntimeError("You must install glib-compile-schemas to run "
+            "virt-manager from git.")
 
     os.environ["GSETTINGS_SCHEMA_DIR"] = schemadir
-    ret = subprocess.call(["glib-compile-schemas", "--strict", schemadir])
+    ret = subprocess.call([exe, "--strict", schemadir])
     if ret != 0:
         raise RuntimeError("Failed to compile local gsettings schemas")
 
 
-__version__ = "1.0.1"
+__version__ = "1.1.0"
 
 __snapshot__ = 0
 
@@ -88,3 +94,4 @@ hv_packages = _split_list(_get_param("hv_packages", ""))
 askpass_package = _split_list(_get_param("askpass_packages", ""))
 libvirt_packages = _split_list(_get_param("libvirt_packages", ""))
 default_graphics = _get_param("default_graphics", "spice")
+with_bhyve = bool(int(_get_param("with_bhyve", "0")))
